==> nextcloud-13.0.1.tgz: nextcloud/apps/federatedfilesharing/l10n/pt_PT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Partilha Federada",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Pretende adicionar a partilha remota {nome} de {proprietório}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Partilha servidor-para-servidor não está activa neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer uma partilha federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer a partilha federada, a palavra-passe talvez esteja incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Pedido de Partilha Federada enviado, irá receber o convite. Confira as suas notificações.",
    "The mountpoint name contains invalid characters." : "O ponto de montagem (mountpoint) contem caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "Não é permitido criar partilha federada com o proprietário. ",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível a autenticação na partilha remota, a palavra passe talvez esteja incorrecta",
    "Storage not valid" : "Armazenamento inválido",
    "Federated share added" : "Partilha federada adicionada",
    "Couldn't add remote share" : "Não foi possível adicionar partilha remota",
    "Sharing %s failed, because this item is already shared with %s" : "A partilha %s falhou, porque este item já está a ser partilhado com %s",
    "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
    "File is already shared with %s" : "O ficheiro já foi partilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Partilha %s falhou, não foi possível encontrar %s, o servidor pode estar actualmente inatingível ou usa um certificado auto-assinado. ",
    "Could not find share" : "Não foi possível encontrar partilha",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recebeu \"%3$s\" como uma partilha remota de %1$s (em nome de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Recebeu {partilha} como uma partilha remota de {utilizador} (em nome de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Recebeu \"%3$s\" como uma partilha remota de %1$s",
    "You received {share} as a remote share from {user}" : "Recebeu {partilha} como uma partilha remota de {utilizador}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud, veja %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud",
    "Sharing" : "Partilha",
    "Federated file sharing" : "Partilha federada de ficheiros",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Adjust how people can share between servers." : "Ajustar como as pessoas podem partilhar entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir que os utilizadores neste servidor enviem as partilhas para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os utilizadores neste servidor recebam as partilhas de outros servidores",
    "Search global and public address book for users" : "Pesquisar lista global e pública de contactos de utilizadores  ",
    "Allow users to publish their data to a global and public address book" : "Permitir que  os utilizadores publiquem os seus dados para uma lista de contactos global e pública",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode partilhar com qualquer pessoa que use Nextcloud, ownCloud ou Pydio! Basta inserir Cloud ID federado no diálogo de partilha. Deve ser idêntico a pessoa@cloud.exemplo.com",
    "Your Federated Cloud ID:" : "A sua id. da Nuvem Federada:",
    "Share it so your friends can share files with you:" : "Partilhe para que os seus amigos possam partilhar ficheiros consigo:",
    "Add to your website" : "Adicione ao seu site da Web",
    "Share with me via Nextcloud" : "Partilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Search global and public address book for users and let local users publish their data" : "Pesquisar por utilizadores na lista de endereços global e pública e permita que utilizadores locais publiquem os seus dados"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/federatedfilesharing/l10n/pt_PT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Partilha Federada",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Pretende adicionar a partilha remota {nome} de {proprietório}@{remoto}?",
    "Remote share" : "Partilha remota",
    "Remote share password" : "Palavra-passe da partilha remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar partilha remota",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "Server to server sharing is not enabled on this server" : "Partilha servidor-para-servidor não está activa neste servidor",
    "Couldn't establish a federated share." : "Não foi possível estabelecer uma partilha federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Não foi possível estabelecer a partilha federada, a palavra-passe talvez esteja incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Pedido de Partilha Federada enviado, irá receber o convite. Confira as suas notificações.",
    "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
    "File is already shared with %s" : "O ficheiro já foi partilhado com %s",
    "Could not find share" : "Não foi possível encontrar partilha",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Recebeu \"%3$s\" como uma partilha remota de %1$s (em nome de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Recebeu {partilha} como uma partilha remota de {utilizador} (em nome de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Recebeu \"%3$s\" como uma partilha remota de %1$s",
    "You received {share} as a remote share from {user}" : "Recebeu {partilha} como uma partilha remota de {utilizador}",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud, veja %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud",
    "Sharing" : "Partilha",
    "Federated file sharing" : "Partilha federada de ficheiros",
    "Provide federated file sharing across servers" : "Permita a partilha federada de ficheiros entre servidores",
    "Federated Cloud Sharing" : "Partilha de Nuvem Federada",
    "Open documentation" : "Abrir documentação",
    "Adjust how people can share between servers." : "Ajustar como as pessoas podem partilhar entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir que os utilizadores neste servidor enviem as partilhas para outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir que os utilizadores neste servidor recebam as partilhas de outros servidores",
    "Search global and public address book for users" : "Pesquisar lista global e pública de contactos de utilizadores  ",
    "Allow users to publish their data to a global and public address book" : "Permitir que  os utilizadores publiquem os seus dados para uma lista de contactos global e pública",
    "Federated Cloud" : "Nuvem Federada",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode partilhar com qualquer pessoa que use Nextcloud, ownCloud ou Pydio! Basta inserir Cloud ID federado no diálogo de partilha. Deve ser idêntico a pessoa@cloud.exemplo.com",
    "Your Federated Cloud ID:" : "A sua id. da Nuvem Federada:",
    "Share it so your friends can share files with you:" : "Partilhe para que os seus amigos possam partilhar ficheiros consigo:",
    "Add to your website" : "Adicione ao seu site da Web",
    "Share with me via Nextcloud" : "Partilhe comigo via Nextcloud",
    "HTML Code:" : "Código HTML:",
    "The mountpoint name contains invalid characters." : "O ponto de montagem (mountpoint) contem caracteres inválidos.",
    "Not allowed to create a federated share with the owner." : "Não é permitido criar partilha federada com o proprietário. ",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível a autenticação na partilha remota, a palavra passe talvez esteja incorrecta",
    "Storage not valid" : "Armazenamento inválido",
    "Federated share added" : "Partilha federada adicionada",
    "Couldn't add remote share" : "Não foi possível adicionar partilha remota",
    "Sharing %s failed, because this item is already shared with %s" : "A partilha %s falhou, porque este item já está a ser partilhado com %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Partilha %s falhou, não foi possível encontrar %s, o servidor pode estar actualmente inatingível ou usa um certificado auto-assinado. "
},
"nplurals=2; plural=(n != 1);");
